# Import module from "stattotex/stattotex.py"
# Add to path
import sys
sys.path.append('stattotex')
from stattotex import stattotex

# Formatted number to save
number = 2532.01
# Format
f_number = '{:,.2f}'.format(number)
stattotex("FormatTest", f_number, "test/testVars.tex", clear_file=True)

# String with a percent sign
pct_string = "0.3%"
stattotex("PctTest", pct_string, "test/testVars.tex")

# Let's try saving another number with the same name to see if it overrides but does not overwrite
pct = 100.3
pct_string = str(pct) + "%"
stattotex("PctTest", pct_string, "test/testVars.tex")

# Try saving a word
if pct > 0.0:
    word = "increased"
elif pct == 0.0:
    word = "stayed the same"
else:
    word = "decreased"
stattotex("WordTest", word, "test/testVars.tex")

# Try saving a number with an underscore in number name
number = 1000
try:
    stattotex("Num_Test", number, "test/testVars.tex")
except ValueError as e:
    err = e
# Throw an error if the try didn't throw a ValueError
if err is None:
    raise "Failed to throw ValueError for variable name with underscore."



import os

def stattotex(variable_name, variable_value, filename, clear_file=False):
    '''
    Function that takes a variable name and value from Python and saves it to a file that allows for easy read-in and automatic updates in LaTeX.

    Parameters:
    - variable_name: The name of the variable for the output LaTeX file
    - variable_value: The value to be saved to the file. Can be a number, number formatted as a string, or a word (numeric or string input)
    - filename: The name of the file to be saved to
    - clear_file: Default is False. If True, the file will be deleted before writing to it. If false it will not be deleted, and the new variable definition will be appended to the end of the file - still superseding any previous definition for the same variable name.
    '''

    # Creating the LaTeX command

    # Cast variable_value as string
    variable_value = str(variable_value)
    # Replace % with \% for LaTeX
    variable_value = variable_value.replace("%", "\%")

    # Throw error if variable_name contains an underscore
    if "_" in variable_name:
        raise ValueError("variable_name cannot contain an underscore. LaTeX does not allow this.")

    # Delete the file if clear_file = True
    if clear_file:
        if os.path.exists(filename):
            os.remove(filename)

    # If prior file exists
    # Check for f"\\newcommand{{\\{variable_name}}}" in the file
    # If it exists, replace the entire line with the new command
    # If it does not exist, set command = f"\\newcommand{{\\{variable_name}}}{{{variable_value}}}"
    if os.path.exists(filename):
        with open(filename, "r") as file:
            if f"\\newcommand{{\\{variable_name}}}" in file.read():
                command = f"\\renewcommand{{\\{variable_name}}}{{{variable_value}}}"
            else:
                command = f"\\newcommand{{\\{variable_name}}}{{{variable_value}}}"
    else:
        command = f"\\newcommand{{\\{variable_name}}}{{{variable_value}}}"

    # Writing the command to the file
    with open(filename, "a") as file:
        file.write(command + "\n")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="stattotex",
    author="Isaac Liu",
    author_email="ijyliu@gmail.com",
    version="0.1.3",
    description="A simple function for automatically updating LaTeX documents with numbers from Python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ijyliu/stattotex-python",
    packages=setuptools.find_packages(),
    license='MIT',
    classifiers=(
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ),
)
